from simpleicons.icon import Icon
icon= Icon(
    title="CEVO",
    slug="cevo",
    hex="1EABE2",
    source="https://cevo.com/",
    svg="""<svg xmlns="http://www.w3.org/2000/svg" role="img" viewBox="0 0 24 24"><title>CEVO icon</title><path d="M3.5 6h12l6 10.3L24 12 18 1.6H6L3.5 6zm-.9 1.5L0 12l6 10.4h12l2.6-4.5-2.5-4.3-2.6 4.5h-7L5 12l2.6-4.5h-5z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
icon= Icon(
    title="Polymer Project",
    slug="polymerproject",
    hex="FF4470",
    source="https://github.com/Polymer/polymer-project.org/tree/master/app/images/logos",
    svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>Polymer Project icon</title><path d="M14.4 3.686L7.2 16.16 4.8 12l4.8-8.314H4.8L0 12l2.4 4.159 2.4 4.155h4.8l7.2-12.469L19.2 12l-4.8 8.314h4.8l2.4-4.155L24 12l-2.4-4.155-2.4-4.159Z"/></svg>
""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
icon= Icon(
    title="Helly Hansen",
    slug="hellyhansen",
    hex="DA2128",
    source="https://www.hellyhansen.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Helly Hansen icon</title><path d="M4.27 10.09h4.08V5.63h4.11L9.98 18.37H8.34V14H4.26v4.37H0V5.63h4.27zm15.45 3.82h-4.07v4.46h-4.1l2.47-12.74h1.64V10h4.08V5.63H24v12.74h-4.28Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
icon= Icon(
    title="Zend",
    slug="zend",
    hex="0679EA",
    source="https://www.zend.com/",
    svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>Zend icon</title><path d="M24 .467L9.01 20.217H20.54A3.46 3.46 0 0024 16.757V.468zM3.459 3.783C1.585 3.783 0 5.153 0 7.1v16.433l15.063-19.75H3.459Z"/></svg>
""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
icon= Icon(
    title="Farfetch",
    slug="farfetch",
    hex="000000",
    source="https://www.farfetch.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Farfetch icon</title><path d="M9.635 0L4.883 4.811V24h4.752v-9.593h7.119V9.6H9.635V4.811h9.482V0Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
icon= Icon(
    title="Ghost",
    slug="ghost",
    hex="738A94",
    source="https://ghost.org/design",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Ghost icon</title><path d="M9.604 19.199H.008V24h9.597v-4.801zm14.39 0h-9.591V24h9.591v-4.801zm.003-9.599H0v4.8h23.997V9.6zM24 0h-4.801v4.801H24V0zm-9.596 0H.008v4.801h14.396V0z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
icon= Icon(
    title="Microsoft Azure",
    slug="microsoftazure",
    hex="0089D6",
    source="https://developer.microsoft.com",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Microsoft Azure icon</title><path d="M5.483 21.3H24L14.025 4.013l-3.038 8.347 5.836 6.938L5.483 21.3zM13.23 2.7L6.105 8.677 0 19.253h5.505v.014L13.23 2.7z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
icon= Icon(
    title="Highly",
    slug="highly",
    hex="FF3C00",
    source="https://highly.co/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Highly icon</title><path d="M10.2 20.4H13.799999999999999V24H10.2zM9 0H15V18H9z"/></svg>""",
    guidelines=None,
    license=None,
)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['simpleicons', 'simpleicons.icons']

package_data = \
{'': ['*']}

install_requires = \
['Pillow>=8.2.0,<9.0.0', 'reportlab>=3.5.67,<4.0.0', 'svglib>=1.1.0,<2.0.0']

entry_points = \
{'console_scripts': ['generate = scripts.build_package:build']}

setup_kwargs = {
    'name': 'simpleicons',
    'version': '4.20.2',
    'description': 'Use a wide-range of icons derived from the simple-icons/simple-icons repo in python.',
    'long_description': '<h1>\n  <img src="logo.svg" alt="create-logo Logo" width="50" height="50">\n  simpleicons\n</h1>\n\nUse a wide-range of icons derived from the [simple-icons](https://github.com/simple-icons/simple-icons) repo in python. Go to [their website](https://simpleicons.org/) for a full list of icons. The slug version must be used for the `icon_name`. The icons folder that accompanies the package has all the files. The package uses [Simple Icons v4.20.0](https://github.com/simple-icons/simple-icons/releases/tag/4.20.0).\n\n## Installation\nInstall with `pip install simpleicons`. Keep in mind that this is a fairly large package due to all the icons (a couple of megabytes).\n\n## Usage\n### General Usage\nThe API can then be used as follows, where [ICON SLUG] is replaced by a slug:\n```py\nfrom simpleicons.all import icons\n\n# Get a specific icon by its slug as:\nicons.get(\'[ICON SLUG]\')\n\n# For example:\nicon = icons.get(\'simpleicons\')\n\nprint(icon.__dict__)\n\n"""\n{\n    \'title\': \'Simple Icons\',\n    \'slug\': \'simpleicons\',\n    \'hex\': \'111111\',\n    \'source\': \'https://simpleicons.org/\',\n    \'svg\': \'<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">...</svg>\',\n    \'path\': \'M12 12v-1.5c-2.484 ...\',\n    \'guidelines\': \'https://simpleicons.org/styleguide\',\n    \'license\': {\n        type: \'...\',\n        url: \'https://example.com/\'\n    }\n}\n"""\n```\nNOTE: The `guidelines` entry will be `None` if we do not yet have guidelines data for the icon.\n\nNOTE: The `license` entry will be `None` if we do not yet have license data for the icon.\n\nAlternatively you can import the needed icons individually, where [ICON SLUG] is replaced by a slug:\n```py\n# Import a specific icon by its slug as:\nfrom simpleicons.icons.[ICON SLUG] import icon\n\n# For example:\nfrom simpleicons.icons.simpleicons import icon\n\nprint(icon)\n```\nNOTE: If the icon\'s slug is not compatible with python imports (e.g. it has a dash) you must use importlib to import it:\n```py\nimport importlib\n\nimportlib.import_module(\'simpleicons.icons.[ICON SLUG]\').icon\n\n# For example:\nimportlib.import_module(\'simpleicons.icons.dot-net\').icon\n```\n\nLastly, the `icons` object is also enumerable. This is useful if you want to do a computation on every icon:\n```py\nfrom simpleicons.all import icons\n\nfor (key, icon in icons) {\n    # do stuff\n}\n```\n\n### XML\nThe XML for each icon can be easily manipulated with either of two functions:\n\n`get_xml(icon_name: str, **attrs) -> ElementTree`\n\n```py\nfrom simpleicons.icon_xml import get_xml\n\n# blue logo (simply adds <svg fill="blue"></svg>)\nget_xml("github", fill="blue")\n```\n\n`get_xml_bytes(icon_name: str, **attrs) -> bytes`\n\n```py\nfrom simpleicons.icon_xml import get_xml_bytes\n\nget_xml_bytes("github", fill="blue")\n```\n\nTo simply get the unparsed XML string for each icon, use `get_str(icon_name: str) -> str`:\n\n```py\nfrom simpleicons.icon_xml import get_str\n\nget_str("github")\n```\n\nThis string representation will allow for quick implementation in web pages, however it cannot be manipulated. Use `get_xml_bytes` for easy web page implementation alongside manipulation.\n\n### Image\nIcons can be converted to PIL Images with `icon_to_image(icon_xml: bytes, bg: int=0xffffff, scale: Tuple[int, int]=(1, 1)) -> Image`:\n\n```py\nfrom simpleicons.icon_xml import get_xml_bytes\nfrom simpleicons.image import icon_to_image\n\nxml_bytes = get_xml_bytes("github", fill="blue")\n\n# black background and x5 scale\nimg = icon_to_image(xml_bytes, bg=0x000000, scale=(5, 5))\n\n# manipulate PIL Image\nimg.putalpha(32)\nimg.save("github.png")\n```\n',
    'author': 'Sachin Raja',
    'author_email': 'sachinraja2349@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from simpleicons.icon import Icon
icon= Icon(
    title="PeerTube",
    slug="peertube",
    hex="F1680D",
    source="https://github.com/Chocobozzz/PeerTube/tree/develop/client/src/assets/images",
    svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>PeerTube icon</title><path d="M12 6.545v10.91L20.727 12M3.273 12v12L12 17.455M3.273 0v12L12 6.545"/></svg>""",
    guidelines=None,
    license=None,
)
